==> nmsg-0.3.3.tar.gz: nmsg-0.3.3/nmsg/res.c <==
/*
 * Copyright (c) 2009 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <stdlib.h>

#include "res.h"

static const char *res_strings[] = {
	[nmsg_res_success]		= "success",
	[nmsg_res_failure]		= "generic failure",
	[nmsg_res_eof]			= "end of file",
	[nmsg_res_memfail]		= "memory allocation failed",
	[nmsg_res_magic_mismatch]	= "incorrect magic number in NMSG header",
	[nmsg_res_version_mismatch]	= "incorrect version number in NMSG header",
	[nmsg_res_pbuf_ready]		= "pbuf payload ready",
	[nmsg_res_nmsg_written]		= "NMSG container written",
	[nmsg_res_notimpl]		= "function not implemented",
	[nmsg_res_stop]			= "stop condition reached",
	[nmsg_res_again]		= "call should be repeated again",
	[nmsg_res_parse_error]		= "parse error",
	[nmsg_res_pcap_error]		= "libpcap error"
};

const char *
nmsg_res_lookup(enum nmsg_res val) {
	if (val > sizeof(res_strings) / sizeof(char *))
		return (NULL);
	return res_strings[val];
}

==> nmsg-0.5.13.tar.gz: nmsg-0.5.13/nmsg/res.c <==
/*
 * Copyright (c) 2009 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <stdlib.h>

#include "res.h"

static const char *res_strings[] = {
	[nmsg_res_success]		= "success",
	[nmsg_res_failure]		= "generic failure",
	[nmsg_res_eof]			= "end of file",
	[nmsg_res_memfail]		= "memory allocation failed",
	[nmsg_res_magic_mismatch]	= "incorrect magic number in NMSG header",
	[nmsg_res_version_mismatch]	= "incorrect version number in NMSG header",
	[nmsg_res_pbuf_ready]		= "pbuf payload ready",
	[nmsg_res_nmsg_written]		= "NMSG container written",
	[nmsg_res_notimpl]		= "function not implemented",
	[nmsg_res_stop]			= "stop condition reached",
	[nmsg_res_again]		= "call should be repeated again",
	[nmsg_res_parse_error]		= "parse error",
	[nmsg_res_pcap_error]		= "libpcap error",
	[nmsg_res_read_failure]		= "read failure"
};

const char *
nmsg_res_lookup(enum nmsg_res val) {
	if (val > sizeof(res_strings) / sizeof(char *))
		return (NULL);
	return res_strings[val];
}
